#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
This module defines unit tests for `ptutils.cli`.
"""
